@@ -1,12 +1,12 @@
 package App::UniqFiles;
 
-our $DATE = '2015-01-03'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any qw($log);
+use Log::Any::IfLOG qw($log);
 
 use Digest::MD5;
 
@@ -214,18 +214,23 @@ App::UniqFiles - Report or omit duplicate file contents
 
 =head1 VERSION
 
-This document describes version 0.09 of App::UniqFiles (from Perl distribution App-UniqFiles), released on 2015-01-03.
+This document describes version 0.10 of App::UniqFiles (from Perl distribution App-UniqFiles), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
  # See uniq-files script
 
+=head1 NOTES
+
+Warning: cannot properly handle symlinks or special files (socket, pipe,
+device), so don't feed them.
+
 =head1 FUNCTIONS
 
 
 =head2 uniq_files(%args) -> [status, msg, result, meta]
 
-Report or omit duplicate file contents.
+{en_US Report or omit duplicate file contents}.
 
 Examples:
 
@@ -247,8 +252,10 @@ List all files which have duplicate contents.
 List number of occurences of contents for each file.
 
 
+{en_US 
 Given a list of filenames, will check each file size and content for duplicate
 content. Interface is a bit like the C<uniq> Unix command-line program.
+}
 
 Arguments ('*' denotes required arguments):
 
@@ -256,25 +263,30 @@ Arguments ('*' denotes required arguments):
 
 =item * B<check_content> => I<bool> (default: 1)
 
-Whether to check file content .
+{en_US Whether to check file content }.
 
+{en_US 
 If set to 0, uniqueness will be determined solely from file size. This can be
 quicker but might generate a false positive when two files of the same size are
 deemed as duplicate even though their content are different.
+}
 
 =item * B<count> => I<bool> (default: 0)
 
-Whether to return each file content's number of occurence.
+{en_US Whether to return each file content's number of occurence}.
 
+{en_US 
 1 means the file content is only encountered once (unique), 2 means there is one
 duplicate, and so on.
+}
 
 =item * B<files>* => I<array[str]>
 
 =item * B<report_duplicate> => I<int> (default: 2)
 
-Whether to return duplicate items.
+{en_US Whether to return duplicate items}.
 
+{en_US 
 Can be set to either 0, 1, 2.
 
 If set to 2 (the default), will only return the first of duplicate items. For
@@ -286,10 +298,11 @@ If set to 1, will return all the the duplicate items. From the above example:
 file1 and file3 will be returned.
 
 If set to 0, duplicate items will not be returned.
+}
 
 =item * B<report_unique> => I<bool> (default: 1)
 
-Whether to return unique items.
+{en_US Whether to return unique items}.
 
 =back
 
@@ -303,10 +316,6 @@ element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (any)
-=head1 NOTES
-
-Warning: cannot properly handle symlinks or special files (socket, pipe,
-device), so don't feed them.
 
 =head1 HOMEPAGE
 
